@@ -72,7 +72,7 @@ def test_completion_install_zsh():
     )
     new_text = completion_path.read_text()
     completion_path.write_text(text)
-    install_script = 'eval "$(_TUTORIAL001.PY_COMPLETE=source_szh tutorial001.py)"'
+    install_script = 'eval "$(_TUTORIAL001.PY_COMPLETE=source_zsh tutorial001.py)"'
     assert install_script not in text
     assert install_script in new_text
     assert "completion installed in" in result.stdout
@@ -83,7 +83,7 @@ def test_completion_install_fish():
     script_path = Path(mod.__file__)
     completion_path: Path = Path.home() / f".config/fish/completions/{script_path.name}.fish"
     text = ""
-    if completion_path.is_file():
+    if completion_path.is_file():  # pragma: nocover
         text = completion_path.read_text()
     result = subprocess.run(
         ["coverage", "run", mod.__file__, "--install-completion", "fish"],
@@ -114,7 +114,7 @@ def test_completion_install_powershell():
     completion_path: Path = Path.home() / f".config/powershell/Microsoft.PowerShell_profile.ps1"
     completion_path_bytes = f"{completion_path}\n".encode("windows-1252")
     text = ""
-    if completion_path.is_file():
+    if completion_path.is_file():  # pragma: nocover
         text = completion_path.read_text()
 
     with mock.patch.object(
@@ -124,7 +124,7 @@ def test_completion_install_powershell():
             subprocess,
             "run",
             return_value=subprocess.CompletedProcess(
-                ["pwsh"], returncode=0, stdout=completion_path_bytes,
+                ["pwsh"], returncode=0, stdout=completion_path_bytes
             ),
         ):
             result = runner.invoke(app, ["--install-completion"])
